@@ -65,9 +65,11 @@ def cluster_config() -> Cluster:
     return Cluster(
         registry_url=URL("https://registry-dev.neu.ro"),
         storage_url=URL("https://storage-dev.neu.ro"),
+        blob_storage_url=URL("https://blob-storage-dev.neu.ro"),
         users_url=URL("https://users-dev.neu.ro"),
         monitoring_url=URL("https://monitoring-dev.neu.ro"),
         secrets_url=URL("https://secrets-dev.neu.ro"),
+        disks_url=URL("https://disks-storage-dev.neu.ro"),
         presets={
             "gpu-small": Preset(
                 cpu=7, memory_mb=30 * 1024, gpu=1, gpu_model="nvidia-tesla-k80"
@@ -80,8 +82,8 @@ def cluster_config() -> Cluster:
             "cpu-large-p": Preset(
                 cpu=7,
                 memory_mb=14 * 1024,
-                is_preemptible=True,
-                is_preemptible_node_required=True,
+                scheduler_enabled=True,
+                preemptible_node=True,
             ),
         },
         name="default",
@@ -106,8 +108,10 @@ def make_client(
                 registry_url=URL(registry_url),
                 monitoring_url=(url / "jobs"),
                 storage_url=(url / "storage"),
+                blob_storage_url=(url / "blob"),
                 users_url=url,
                 secrets_url=(url / "secrets"),
+                disks_url=(url / "disks"),
                 presets={
                     "gpu-small": Preset(
                         cpu=7, memory_mb=30 * 1024, gpu=1, gpu_model="nvidia-tesla-k80"
