@@ -7,6 +7,7 @@ from typing import Any, Callable, Optional
 import pytest
 from dateutil.parser import isoparse
 from rich.console import Console
+from rich.text import Text
 from yarl import URL
 
 from neuro_sdk import (
@@ -85,7 +86,7 @@ def job_descr_no_name() -> JobDescription:
             image=RemoteImage.new_external_image(name="ubuntu", tag="latest"),
             resources=Resources(16, 0.1, 0, None, False, None, None),
         ),
-        is_preemptible=True,
+        scheduler_enabled=True,
         pass_config=True,
     )
 
@@ -111,7 +112,7 @@ def job_descr() -> JobDescription:
             image=RemoteImage.new_external_image(name="ubuntu", tag="latest"),
             resources=Resources(16, 0.1, 0, None, False, None, None),
         ),
-        is_preemptible=True,
+        scheduler_enabled=True,
         pass_config=True,
     )
 
@@ -156,7 +157,7 @@ class TestJobStartProgress:
                     tpu_software_version="1.14",
                 ),
             ),
-            is_preemptible=False,
+            scheduler_enabled=False,
             pass_config=True,
             life_span=life_span,
         )
@@ -268,7 +269,7 @@ class TestJobOutputFormatter:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 http=HTTPPort(port=80, requires_auth=True),
             ),
-            is_preemptible=False,
+            scheduler_enabled=False,
             pass_config=True,
         )
 
@@ -300,7 +301,7 @@ class TestJobOutputFormatter:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 http=HTTPPort(port=80, requires_auth=True),
             ),
-            is_preemptible=False,
+            scheduler_enabled=False,
             pass_config=True,
         )
 
@@ -332,7 +333,7 @@ class TestJobOutputFormatter:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 http=HTTPPort(port=80, requires_auth=True),
             ),
-            is_preemptible=False,
+            scheduler_enabled=False,
             pass_config=True,
         )
 
@@ -363,7 +364,7 @@ class TestJobOutputFormatter:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 http=HTTPPort(port=80, requires_auth=True),
             ),
-            is_preemptible=False,
+            scheduler_enabled=False,
             pass_config=True,
             life_span=1.0 * ((60 * 60 * 24 * 1) + (60 * 60 * 2) + (60 * 3) + 4),
         )
@@ -395,7 +396,7 @@ class TestJobOutputFormatter:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 http=HTTPPort(port=80, requires_auth=True),
             ),
-            is_preemptible=False,
+            scheduler_enabled=False,
             pass_config=True,
             life_span=0.0,
         )
@@ -428,7 +429,7 @@ class TestJobOutputFormatter:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 http=HTTPPort(port=80, requires_auth=True),
             ),
-            is_preemptible=False,
+            scheduler_enabled=False,
             pass_config=True,
             restart_policy=JobRestartPolicy.ALWAYS,
         )
@@ -460,7 +461,7 @@ class TestJobOutputFormatter:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 http=HTTPPort(port=80, requires_auth=True),
             ),
-            is_preemptible=False,
+            scheduler_enabled=False,
             pass_config=True,
         )
 
@@ -485,7 +486,7 @@ class TestJobOutputFormatter:
                 image=RemoteImage.new_external_image(name="test-image"),
                 resources=Resources(16, 0.1, 0, None, False, None, None),
             ),
-            is_preemptible=True,
+            scheduler_enabled=True,
             pass_config=True,
             owner="owner",
             cluster_name="default",
@@ -514,7 +515,7 @@ class TestJobOutputFormatter:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 tty=True,
             ),
-            is_preemptible=True,
+            scheduler_enabled=True,
             pass_config=True,
             owner="owner",
             cluster_name="default",
@@ -542,7 +543,7 @@ class TestJobOutputFormatter:
                 command="test-command",
                 resources=Resources(16, 0.1, 0, None, False, None, None),
             ),
-            is_preemptible=True,
+            scheduler_enabled=True,
             pass_config=True,
             owner="owner",
             cluster_name="default",
@@ -574,7 +575,7 @@ class TestJobOutputFormatter:
                 image=RemoteImage.new_external_image(name="test-image"),
                 resources=Resources(16, 0.1, 0, None, False, None, None),
             ),
-            is_preemptible=False,
+            scheduler_enabled=False,
             pass_config=True,
             internal_hostname="host.local",
         )
@@ -605,7 +606,7 @@ class TestJobOutputFormatter:
                 image=RemoteImage.new_external_image(name="test-image"),
                 resources=Resources(16, 0.1, 0, None, False, None, None),
             ),
-            is_preemptible=False,
+            scheduler_enabled=False,
             pass_config=True,
             internal_hostname="host.local",
             internal_hostname_named="test-job--test-owner.local",
@@ -637,7 +638,7 @@ class TestJobOutputFormatter:
                 image=RemoteImage.new_external_image(name="test-image"),
                 resources=Resources(16, 0.1, 0, None, False, None, None),
             ),
-            is_preemptible=False,
+            scheduler_enabled=False,
             pass_config=True,
             internal_hostname="host.local",
         )
@@ -677,7 +678,7 @@ class TestJobOutputFormatter:
                 http=HTTPPort(port=80, requires_auth=True),
                 env={"ENV_NAME_1": "__value1__", "ENV_NAME_2": "**value2**"},
             ),
-            is_preemptible=False,
+            scheduler_enabled=False,
             pass_config=True,
         )
 
@@ -732,7 +733,7 @@ class TestJobOutputFormatter:
                     ),
                 ],
             ),
-            is_preemptible=False,
+            scheduler_enabled=False,
             pass_config=True,
         )
 
@@ -782,7 +783,7 @@ class TestJobOutputFormatter:
                     ),
                 ],
             ),
-            is_preemptible=False,
+            scheduler_enabled=False,
             pass_config=True,
         )
 
@@ -846,7 +847,7 @@ class TestJobOutputFormatter:
                     "ENV_NAME_3": URL("secret://othercluster/otheruser/secret6"),
                 },
             ),
-            is_preemptible=False,
+            scheduler_enabled=False,
             pass_config=True,
         )
 
@@ -901,7 +902,7 @@ class TestJobOutputFormatter:
                     ),
                 ],
             ),
-            is_preemptible=False,
+            scheduler_enabled=False,
             pass_config=True,
         )
 
@@ -940,7 +941,7 @@ class TestJobOutputFormatter:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 http=HTTPPort(port=80, requires_auth=True),
             ),
-            is_preemptible=False,
+            scheduler_enabled=False,
             pass_config=True,
         )
 
@@ -966,7 +967,7 @@ class TestJobOutputFormatter:
                 image=RemoteImage.new_external_image(name="test-image"),
                 resources=Resources(16, 0.1, 0, None, False, None, None),
             ),
-            is_preemptible=False,
+            scheduler_enabled=False,
             pass_config=True,
             owner="owner",
             cluster_name="default",
@@ -994,8 +995,8 @@ class TestJobOutputFormatter:
                 image=RemoteImage.new_external_image(name="test-image"),
                 resources=Resources(16, 0.1, 0, None, False, None, None),
             ),
-            is_preemptible=True,
-            is_preemptible_node_required=True,
+            scheduler_enabled=True,
+            preemptible_node=True,
             pass_config=True,
             owner="owner",
             cluster_name="default",
@@ -1112,7 +1113,7 @@ class TestSimpleJobsFormatter:
                     image=RemoteImage.new_external_image(name="ubuntu", tag="latest"),
                     resources=Resources(16, 0.1, 0, None, False, None, None),
                 ),
-                is_preemptible=True,
+                scheduler_enabled=True,
                 pass_config=True,
             ),
             JobDescription(
@@ -1134,7 +1135,7 @@ class TestSimpleJobsFormatter:
                     image=RemoteImage.new_external_image(name="ubuntu", tag="latest"),
                     resources=Resources(16, 0.1, 0, None, False, None, None),
                 ),
-                is_preemptible=True,
+                scheduler_enabled=True,
                 pass_config=True,
             ),
         ]
@@ -1172,7 +1173,7 @@ class TestTabularJobRow:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 command="ls",
             ),
-            is_preemptible=True,
+            scheduler_enabled=True,
             pass_config=True,
         )
 
@@ -1208,7 +1209,7 @@ class TestTabularJobRow:
         row = TabularJobRow.from_job(
             self._job_descr_with_status(status), "owner", image_formatter=str
         )
-        assert row.status == f"[{color}]{status}[/{color}]"
+        assert row.status == Text(status, style="color")
         assert row.when == date
 
     def test_image_from_registry_parsing_short(self) -> None:
@@ -1287,7 +1288,7 @@ class TestTabularJobsFormatter:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 command="c",
             ),
-            is_preemptible=True,
+            scheduler_enabled=True,
             pass_config=True,
         )
         formatter = TabularJobsFormatter(
@@ -1328,7 +1329,7 @@ class TestTabularJobsFormatter:
                     resources=Resources(16, 0.1, 0, None, False, None, None),
                     command="ls -la /some/path",
                 ),
-                is_preemptible=True,
+                scheduler_enabled=True,
                 pass_config=True,
             ),
             JobDescription(
@@ -1361,7 +1362,7 @@ class TestTabularJobsFormatter:
                     resources=Resources(16, 0.1, 0, None, False, None, None),
                     command="ls -la /some/path",
                 ),
-                is_preemptible=True,
+                scheduler_enabled=True,
                 pass_config=True,
             ),
         ]
@@ -1392,7 +1393,7 @@ class TestTabularJobsFormatter:
                 resources=Resources(16, 0.1, 0, None, False, None, None),
                 command="c",
             ),
-            is_preemptible=True,
+            scheduler_enabled=True,
             pass_config=True,
         )
 
@@ -1424,7 +1425,7 @@ class TestTabularJobsFormatter:
                     resources=Resources(16, 0.1, 0, None, False, None, None),
                     command="c",
                 ),
-                is_preemptible=True,
+                scheduler_enabled=True,
                 pass_config=True,
                 life_span=life_span,
             )
@@ -1484,7 +1485,7 @@ class TestTabularJobsFormatter:
                     image=RemoteImage.new_external_image(name="test-image"),
                     resources=Resources(16, 0.1, 0, None, False, None, None),
                 ),
-                is_preemptible=False,
+                scheduler_enabled=False,
                 pass_config=True,
                 internal_hostname="host.local",
             )
@@ -1519,7 +1520,7 @@ class TestTabularJobsFormatter:
                     resources=Resources(16, 0.1, 0, None, False, None, None),
                     working_dir=working_dir,
                 ),
-                is_preemptible=False,
+                scheduler_enabled=False,
                 pass_config=True,
                 internal_hostname="host.local",
             )
